@@ -1,6 +1,12 @@
-str_match_all_variable <- structure(function
-### Extract each occurance of a named capture regex pattern from one
+str_match_all_variable <- structure(function # All matches from one subject, variable argument syntax
+### Extract all matches of a named capture regex pattern from one
 ### subject string.
+### It is for the common case of extracting
+### all matches of a regex from a single multi-line text file subject;
+### for other subjects, str_match_all_named can be used to find all matches.
+### This function uses
+### variable_args_list to analyze the arguments and
+### str_match_all_named to perform the matching.
 (...
 ### subject, name1=pattern1, fun1, etc, which creates the regex
 ### (?<name1>pattern1) and uses fun1 for conversion. The first
@@ -23,10 +29,9 @@ str_match_all_variable <- structure(function
     collapse="\n")
   str_match_all_named(subject, L$pattern, L$fun.list)[[1]]
 ### matrix or data.frame with one row for each match, and one column
-### for each named group, see ?str_match_all_named for details.
+### for each named group, see str_match_all_named for details.
 }, ex=function(){
 
-  library(namedCapture)
   chr.pos.vec <- c(
     "chr10:213,054,000-213,055,000",
     "chrM:111,000-222,000",
@@ -38,20 +43,27 @@ str_match_all_variable <- structure(function
   ## lines (and ignores NA elements). Named arguments are used to
   ## create named capture groups, and conversion functions such as
   ## keep.digits are used to convert the previously named group.
-  (match.df <- str_match_all_variable(
+  int.pattern <- list("[0-9,]+", keep.digits)
+  (match.df <- namedCapture::str_match_all_variable(
     chr.pos.vec,
-    chrom="chr.*?",
+    name="chr.*?",
     ":",
-    chromStart=".*?", keep.digits,
+    chromStart=int.pattern,
     "-",
-    chromEnd="[0-9,]*", keep.digits))
+    chromEnd=int.pattern))
   str(match.df)
+  match.df["chr1", "chromEnd"]
 
 })
 
-str_match_variable <- structure(function
-### Extract the first occurance of a named capture regex pattern from
-### each of several subject strings.
+str_match_variable <- structure(function # First match from multiple subjects, variable argument syntax
+### Extract the first match of a named capture regex pattern from each
+### of several subject strings. This function uses variable_args_list
+### to analyze the arguments and str_match_named to perform the
+### matching. For the first match in every row of a data.frame, using
+### a different regex for each column, use df_match_variable. For all
+### matches in one character subject use str_match_all_variable; for
+### all matches in several character subjects use str_match_all_named.
 (...
 ### subject, name1=pattern1, fun1, etc, which creates the regex
 ### (?P<name1>pattern1) and uses fun1 for conversion. The first
@@ -66,36 +78,72 @@ str_match_variable <- structure(function
 ### pattern. Lists are parsed recursively for convenience.
 ){
   L <- variable_args_list(...)
+  ##alias<< namedCapture
   str_match_named(L$subject.vec, L$pattern, L$fun.list)
 ### matrix or data.frame with one row for each subject, and one column
-### for each named group, see ?str_match_named for details.
+### for each named group, see str_match_named for details.
 }, ex=function(){
 
-  library(namedCapture)
-  chr.pos.vec <- c(
-    "chr10:213,054,000-213,055,000",
-    "chrM:111,000-222,000",
-    "this will not match",
-    NA, # neither will this.
-    "chr1:110-111 chr2:220-222") # two possible matches.
-  keep.digits <- function(x)as.integer(gsub("[^0-9]", "", x))
-  ## str_match_variable finds the first match in each element of
-  ## the subject character vector. Named arguments are used to create
-  ## named capture groups, and conversion functions such as
-  ## keep.digits are used to convert the previously named group.
-  (match.df <- str_match_variable(
-    chr.pos.vec,
+  named.subject.vec <- c(
+    ten="chr10:213,054,000-213,055,000",
+    M="chrM:111,000",
+    one="chr1:110-111 chr2:220-222") # two possible matches.
+  ## str_match_variable finds the first match in each element of the
+  ## subject character vector. Named arguments are used to create
+  ## named capture groups, which become column names in the
+  ## result. Since the subject is named, those names are used for the
+  ## rownames of the result.
+  (mat.subject.names <- namedCapture::str_match_variable(
+    named.subject.vec,
     chrom="chr.*?",
     ":",
-    chromStart=".*?", keep.digits,
-    "-",
-    chromEnd="[0-9,]*", keep.digits))
-  str(match.df)
+    chromStart="[0-9,]+",
+    list( # un-named list becomes non-capturing group.
+      "-",
+      chromEnd="[0-9,]+"
+    ), "?")) # chromEnd is optional.
+
+  ## When no type conversion functions are specified, the result is a
+  ## character matrix.
+  str(mat.subject.names)
+
+  ## Conversion functions are used to convert the previously named
+  ## group, and patterns may be saved in lists for re-use.
+  keep.digits <- function(x)as.integer(gsub("[^0-9]", "", x))
+  int.pattern <- list("[0-9,]+", keep.digits)
+  range.pattern <- list(
+    name="chr.*?", # will be used for rownames when subject is un-named.
+    ":",
+    chromStart=int.pattern,
+    list(
+      "-",
+      chromEnd=int.pattern
+    ), "?")
+
+  ## Rownames taken from subject if it has names.
+  (df.subject.names <- namedCapture::str_match_variable(
+    named.subject.vec, range.pattern))
+
+  ## Conversion functions used to create non-char columns.
+  str(df.subject.names)
+
+  ## Rownames taken from name group if subject is un-named.
+  namedCapture::str_match_variable(
+    unname(named.subject.vec), range.pattern)
+
+  ## NA used to indicate no match or missing subject.
+  na.vec <- c(
+    nomatch="this will not match",
+    missing=NA, # neither will this.
+    named.subject.vec)
+  namedCapture::str_match_variable(
+    na.vec, range.pattern)
 
 })
 
 variable_args_list <- function
-### Parse the variable-length argument list.
+### Parse the variable-length argument list used in
+### str_match_variable, str_match_all_variable, and df_match_variable.
 (...
 ### character vectors or functions (for converting extracted character
 ### vectors to other types). The first element must be the subject
